@@ -8,6 +8,7 @@ from ella.articles.models import Article
 # marker to use in content markup to separate the pages
 CONTENT_SPLIT_MARKER = '<!--PB-->'
 
+
 def get_contents(self):
     """
     Returns list of splitted contents by CONTENT_SPLIT_MARKER or None if 
@@ -15,11 +16,12 @@ def get_contents(self):
     """
     if not hasattr(self, '__split_contents'):
         if self.content is not None:
-            self.__split_contents = self.content.content.split(CONTENT_SPLIT_MARKER)
+            self.__split_contents = self.content.split(CONTENT_SPLIT_MARKER)
         else:
             return None
     return self.__split_contents
 
+
 def get_content_count(self):
     """
     Returns count of splitted contents. 
@@ -29,6 +31,7 @@ def get_content_count(self):
         return len(contents)
     return 0
 
+
 def get_content(self, index):
     """
     Returns content of given index.
@@ -38,7 +41,7 @@ def get_content(self, index):
             return self.get_contents()[index]
         except IndexError:
             pass
-    
+
 Article.get_contents = get_contents
 Article.get_content_count = get_content_count
-Article.get_content = get_content
\ No newline at end of file
+Article.get_content = get_content
